---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Expected behaviour**
A clear and concise description of what you'd like to happen if you do x.

**Current behaviour**
A clear and concise description of the current behaviour when you do x. If completely new feature, leave empty.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here. If relevant please also provide version of the plugin and information on the system you are running it on.
